@@ -18,7 +18,7 @@ from ansys.fluent.core.session import _BaseSession as Fluent  # noqa: F401
 from ansys.fluent.core.utils.logging import LOG
 from ansys.fluent.core.utils.setup_for_fluent import setup_for_fluent  # noqa: F401
 
-_VERSION_INFO = "Build date: January 17, 2023 15:37 UTC ShaID: 4af0df1"
+_VERSION_INFO = "Build date: March 17, 2023 12:25 UTC ShaID: e260d31d4"
 """Global variable indicating the version of the PyFluent package - Empty by default"""
 
 _THIS_DIRNAME = os.path.dirname(__file__)
@@ -97,3 +97,9 @@ except Exception:
     pass
 
 BUILDING_GALLERY = False
+
+# Set this to False to stop automatically inferring and setting REMOTING_SERVER_ADDRESS
+INFER_REMOTING_IP = True
+
+# Time in second to wait for response for each ip while inferring remoting ip
+INFER_REMOTING_IP_TIMEOUT_PER_IP = 2
