@@ -1,16 +1,12 @@
 import os
 from pathlib import Path
-import socket
 import subprocess
 import tempfile
 import time
 from typing import List
 
-
-def _get_free_port() -> int:
-    sock = socket.socket()
-    sock.bind(("", 0))
-    return sock.getsockname()[1]
+from ansys.fluent.core.session import parse_server_info_file
+from ansys.fluent.core.utils.networking import get_free_port
 
 
 def start_fluent_container(mounted_from: str, mounted_to: str, args: List[str]) -> int:
@@ -19,25 +15,28 @@ def start_fluent_container(mounted_from: str, mounted_to: str, args: List[str])
     Parameters
     ----------
     mounted_from : str
-        Path to mount from. ``mounted_from`` will be mounted as ``mount_to``
-        within the container.
+        Path to mount from. Within the container, ``mounted_from`` is mounted as
+        ``mount_to``.
     mounted_to : str
-        Path to mount to. ``mounted_from`` will be mounted as ``mount_to``
-        within the container.
+        Path to mount to. Within the container, ``mounted_from`` is mounted as
+        ``mount_to``.
     args : List[str]
-        List of Fluent launch arguments
+        List of Fluent launch arguments.
 
     Returns
     -------
     int
-        gPRC server port exposed from container
+        gPRC server port exposed from the container.
     """
     fd, sifile = tempfile.mkstemp(suffix=".txt", prefix="serverinfo-", dir=mounted_from)
     os.close(fd)
     timeout = 100
     license_server = os.environ["ANSYSLMD_LICENSE_FILE"]
-    port = _get_free_port()
+    port = get_free_port()
+    password = ""
     container_sifile = mounted_to + "/" + Path(sifile).name
+    image_tag = os.getenv("FLUENT_IMAGE_TAG", "v23.1.0")
+    test_name = os.getenv("PYFLUENT_TEST_NAME", "none")
 
     try:
         subprocess.run(
@@ -54,10 +53,10 @@ def start_fluent_container(mounted_from: str, mounted_to: str, args: List[str])
                 f"ANSYSLMD_LICENSE_FILE={license_server}",
                 "-e",
                 f"REMOTING_PORTS={port}/portspan=2",
-                "-e",
-                "FLUENT_LAUNCHED_FROM_PYFLUENT=1",
-                "ghcr.io/pyansys/pyfluent",
-                "-g",
+                "-l",
+                f"test_name={test_name}",
+                f"ghcr.io/pyansys/pyfluent:{image_tag}",
+                "-gu",
                 f"-sifile={container_sifile}",
             ]
             + args
@@ -67,12 +66,13 @@ def start_fluent_container(mounted_from: str, mounted_to: str, args: List[str])
         while True:
             if os.stat(sifile).st_mtime > sifile_last_mtime:
                 time.sleep(1)
+                _, _, password = parse_server_info_file(sifile)
                 break
             if timeout == 0:
                 break
             time.sleep(1)
             timeout -= 1
-        return port
+        return port, password
     except OSError:
         pass
     finally:
